summaryrefslogtreecommitdiff
path: root/compiler/typecheck/TcDerivUtils.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/typecheck/TcDerivUtils.hs')
-rw-r--r--compiler/typecheck/TcDerivUtils.hs14
1 files changed, 7 insertions, 7 deletions
diff --git a/compiler/typecheck/TcDerivUtils.hs b/compiler/typecheck/TcDerivUtils.hs
index 9ff82eee84..c998ea0ee9 100644
--- a/compiler/typecheck/TcDerivUtils.hs
+++ b/compiler/typecheck/TcDerivUtils.hs
@@ -27,14 +27,14 @@ import GhcPrelude
import Bag
import BasicTypes
-import Class
-import DataCon
+import GHC.Core.Class
+import GHC.Core.DataCon
import GHC.Driver.Session
import ErrUtils
import GHC.Driver.Types (lookupFixity, mi_fix)
import GHC.Hs
import Inst
-import InstEnv
+import GHC.Core.InstEnv
import GHC.Iface.Load (loadInterfaceForName)
import Module (getModule)
import Name
@@ -48,9 +48,9 @@ import TcOrigin
import TcRnMonad
import TcType
import THNames (liftClassKey)
-import TyCon
-import TyCoPpr (pprSourceTyCon)
-import Type
+import GHC.Core.TyCon
+import GHC.Core.TyCo.Ppr (pprSourceTyCon)
+import GHC.Core.Type
import Util
import VarSet
@@ -912,7 +912,7 @@ cond_isEnumeration _ _ rep_tc
why = sep [ quotes (pprSourceTyCon rep_tc) <+>
text "must be an enumeration type"
, text "(an enumeration consists of one or more nullary, non-GADT constructors)" ]
- -- See Note [Enumeration types] in TyCon
+ -- See Note [Enumeration types] in GHC.Core.TyCon
cond_isProduct :: Condition
cond_isProduct _ _ rep_tc